clear all; close all; clc

%% Load Apple's data
load 'ApplePrices.mat'

% prices for last 2 years
data{2} = ApplePrices;

% prices for last year
data{1} = ApplePrices(253:end);

s0 = data{1}(end);

nbSample = length( data );

%% Option's information

maturityInDays  = [ 24; 63; 255];  %trading days (according to Apple stock)
K = 350;
nbOption        = length( maturityInDays );
marketValue     = [11.10; 18.65; 43.17];

% libor rates for different maturities
libor = [0.0026; 0.0030; 0.0078]; % Libor is not a compounded rate

h = 1/252; % convention on the number of trading days
tau = (maturityInDays)*h;  
r = log(1+libor);

%% memory allocation
callPrices  = zeros( nbOption, nbSample );
callVega    = zeros( nbOption, nbSample );
callError   = zeros( nbOption, nbSample );

%% Computing prices and vegas

for ii = 1:nbSample
      
    % estimation
    [mu, sigma, err_mu, err_sig, V] = EstBS1dExp(data{ii},h);
    
    callPrices( :, ii ) = FormulaBS( s0, 350, r, tau, sigma);
    
   [DeltaCall, DeltaPut,Gamma,Vega]  = FormulaBSGreeks(  s0, K, r, tau, sigma)
           
        callError(:, ii )  = err_sig * Vega;
        
   
    
end

%% Output
fprintf('\n')
criticalValue = norminv( 0.975 );
for ii = 1:nbOption
    fprintf( '%3d \t\t %4.2f \t\t %6.4f +/- %6.4f \t\t %6.4f +/- %6.4f \n', maturityInDays(ii), marketValue(ii), callPrices(ii,1), callError(ii,1), callPrices(ii,2), callError(ii,2) )
end


%5 Implied vol
fprintf('Implied volatilities\n')
vol = ImpliedVolBS(s0,K,r,tau,marketValue)