function vol = ImpliedVolBS(S,K,r,tau,Call)
% This function computes the implied volatility of a European call option
% under the Black-Scholes-Mertom model. 
%
% Input 
%        S: current price of the underlying asset;
%        K: strike price; 
%        r: (continuous) short-time interest rate for the period;
%        tau: time to maturity;
%        Call: market value of the call.
%
% N.B. All parameters can be vectors. If there is more than one, then they
% must have the same dimension.
%
% Output
%         Call: value of the European call,
%         Put : value of the European put.

n = length(Call);

 sigma0 = 0.2*ones(n,1);
 
 options         = optimset('MaxFunEvals',5000,'MaxIter',2000,'Display','off');

 vol = fsolve(@(x)F(x,S,K,r,tau,Call),sigma0,options);

end

function [y] = F(sigma,S,K,r,tau,Call)

y = Call-FormulaBS(S,K,r,tau,sigma);

end

