function [S,t] = SimBS(mu, covMat, s0, h, n)
% This function generates correlated  Geometric Brownian 
% motions with parameters mu and covMat, observed at 
% n+1 points, with initial value s0. The time between 
% observations is h.
%
% Input 
%         mu: vector of means (dx1 vector); 
%         covMat: covariance matrix (dxd); 
%         h : time step (scalar); 
%         s0: initial values (dx1 vector);
%         n : length (scalar).
%
% Output
%          S: simulated series;
%          t: observation times.
%
%
%  Example:
% [S,t] = SimBS([0.05;-0.01],[0.01 0;0 0.05],[100;110],1/252,252);
 
% time vector
t = [0; h * (1:1:n)'];

% simulate geometric Brownian motions
dim = length( mu );
S = repmat( s0', n+1, 1) .* exp( cumsum( [zeros( 1, dim );...
    repmat( ( mu(:)' - 0.5 * diag( covMat )' ) * h, n, 1) ...
    + sqrt( h ) * randn( n, dim ) * chol( covMat ) ] ) );