function [ksstat, pValue, q95] = GofGauss1dKS( X, N )
% Durbin test for normality using Kolmogorov-Smirnov statistic
% with a P-value calculated with N Monte Carlo simulations.
%
% Input : X: series of observations (assumed i.i.d.) (n x 1);
%         N: number of iterations for estimating the P-value.
%
% Output: ksstat: Kolmogorov-Smirnov Mises test statistic;
%         pvalue: estimated p-value (%) of dbstat;
%         q95   : 95% quantile under the null hypothesis.
%

n = length(X);

t       = (1:n)' / n;
mu0     = mean(X);
std0    = std(X);

Z = ( X - mu0 ) / std0;
U = sort( normcdf( Z ) );

sn  = sqrt( n );
V   = max( abs( U-t ) );
V1  = max( abs( U-t+1 / n ) );
ksstat = sn * max( V, V1 );

if nargin < 2
    pValue = NaN;
    q95    = NaN;
else

KS = zeros(N,1);
for j = 1:N
    
    XX      = randn(n,1);
    
    ZZ = ( XX - mean(XX) ) / std(XX);
    
    UU = sort(normcdf(ZZ));
    
    VV  = max( abs( UU-t ) );
    VV1 = max( abs( UU-t+1 / n ) );
    
    KS(j) = sn * max( VV, VV1 );
    
end

pValue = 100*mean( (KS > ksstat) );
q95    = quantile(KS,0.95);
end