function out = SerIndLBTest(x,Lag,graph)
% This function implements the Ljung-Box test of serial independence, using 
% a circular definition.
%
% Input
%    x: observations ( n x 1 matrix) assumed to be i.i.d.;
%    Lag: number of lags to be considered;
%    graph: if 1, the correlogram is computed; the default is 0.
%
% Output 
%   List containing
%     rho: vector of autocorrelations;
%     LJStat: Ljung-Box statistic;
%     pvalue: pvalue (%) of the Ljung-Box test.
%
% 

%% Simulation

if nargin < 2
    Lag=20;
    graph = 0;
elseif nargin <3;
    graph = 0;
end

n = length(x);
p = Lag+1;
m = mean(x);
s = std(x);

%% circular definition
xx = zeros(n,p);
xx(:,1)=x;
for j=2:p
    xx(:,j) = [x(j:end);x(1:(j-1))];
end
cor_mat = corr(xx);

rho = cor_mat(2:end,1); %autocorrelations

% rho = zeros(Lag,1);
% for j=1:Lag
%    x1 = (x(1:(n-j))-m)/s;
%    x2 = (x((1+j):end)-m)/s;
%    rho(j) = mean(x1.*x2);
% end
    
lags = (1:Lag)';
tt = n-lags;
R2  = rho.^2;
LJStat = n*(n+2)*sum(R2./tt);

Pvalue = 100*(1-chi2cdf(LJStat,Lag));



 out.LJStat = LJStat;
 out.pvalue = Pvalue;
 out.rho    = rho;

%%
if(graph)
    lags = (1:Lag)';
  figure
  ligne = ones(Lag,1)*2/sqrt(n);
   lineHandles = stem(lags,rho,'filled','r-o');
        set(lineHandles(1),'MarkerSize',4);
    
    hold on
    plot(ligne,'--')
    hold on 
    plot(-ligne,'--');
    set(gca,'XLim',[0.7 (Lag+.3)]);
    set(gca,'XTick',lags);
    xlabel('Lags')
    ylabel('Autocorrelations')
    title('Correlogram')  
   %% printed output
    fprintf('Ljung-Box test using the first  %d lags\n\n',Lag);

    fprintf('Ljung-Box Stat: %4.2f    P-value: %3.2f%% \n\n',LJStat,Pvalue);
end


