function q = CornishFisher( y, kappa )
% Cornish-Fisher  expansion of a the inverse Q
% of a distribution function F
%
% Input
%       y: point of evalation of the approximation;
%       kappa: first six cimulants.
%
% Output
%       g: Cornish-Fisher expansion of Q at point y.
%

z = norminv(y);

n       = length(y);
mu      = kappa(1);
sigma   =  sqrt(kappa(2));

%z = (y-mu)/sigma;

for j=1:4
    gam(j) = kappa(j+2)/sigma^(j+2);
end


for j = 1:n
    
    x = z(j);
    
    h1 = H(2,x) / 6;
    h2 = H(3,x) / 24;
    h11 = - ( 2 * H(3,x) + H(1,x) ) / 36;
    h3 = H(4,x) / 120;
    h12 = -( H(4,x) + H(2,x) ) / 24;
    h111 = ( 12 * H(4,x) + 19 * H(2,x) ) / 324;
    h4 = H(5,x) / 720;
    h22 = - ( 3 * H(5,x) + 6 * H(3,x) + 2 * H(1,x) ) / 384;
    h13 = - ( 2 * H(5,x) + 3 * H(3,x) ) / 180;
    h112 = ( 14 * H(5,x) + 37 * H(3,x) + 8 * H(1,x) ) / 288;
    h1111 = - ( 252 * H(5,x) + 832 * H(3,x) + 227 * H(1,x) ) / 7776;
    
    w = x + gam(1) * h1 + gam(2) * h2+ gam(1) * gam(1) * h11 + gam(3) * h3 + gam(1) * gam(2) * h12 ...
        + gam(1) * gam(1) * gam(1) * h111 ... 
        + gam(4) * h4 + gam(2) * gam(2) * h22 + gam(1) * gam(3) * h13 ...
        + gam(1) * gam(1) * gam(2) * h112 + gam(1) * gam(1) * gam(1) * gam(1) * h1111;
    
    q(j)= mu+sigma*w;
    
end
end
function v = H(k,x)
% Polynomials related to Hermite polynomials and appearing in nthe
% Edgeworth and Cornish-Fisher expansions.
%
%  Input: k: order of the polynomial

order = (0:1:floor( 0.5 * k ))';

v = sum(  (-1).^order .* factorial( k ) .* x.^(k-2*order) ./...
    ( 2.^order .* factorial(order) .* factorial( k-2*order ) ) );

end