%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Demo of the accuracy of the Cornish-Fisher expansion for a
% chi-square distribution as a function of its degrees of freedom
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%  log(M(t)) = -(nu(ii)/2)log(1-2t)

x = 0.005:0.005:0.995;

nu = [0.5; 2; 5; 25; 100];
nbNu = length( nu );

for ii = 1:nbNu
    
    for j=1:6
        kappa(j) = nu(ii) * 2^(j-1) * factorial(j-1);
    end
    
    g = CornishFisher( x, kappa );
    
    g1 = chi2inv( x, nu(ii) );
    
    figure
    plot(x,g,'r-');
    hold on
    plot(x,g1,'b-');
    title(['Cornish-Fisher expansion of a chi-square distribution with ',...
        num2str( nu(ii), '%3.0f'), ' degrees of freedom']);
    legend( {'Cornish-Fisher','Real quantile function'}, 'location', 'best');
    hold off

end