%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Demo of the accuracy of the Edgeworth expansion for a
% chi-square distribution as a function of its degrees of freedom
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%  log(M(t)) = -(nu/2)log(1-2t)

nu = [0.5; 2; 5; 25; 100];
nbNu = length( nu );

xLimit = [5; 10; 25; 50; 200];

for ii = 1:nbNu
    
    for j = 1:6
        kappa(j) = nu(ii) * 2^(j-1) * factorial(j-1);
    end
    
    x = 0:0.1:xLimit(ii);
    
    g = EdgeworthCdf( x, kappa );
    
    g1 = chi2cdf( x, nu(ii) );
    
    figure
    plot(x,g,'r-');
    hold on
    plot(x,g1,'b-');
    title(['Edgeworth expansion of a chi-square distribution with ', ...
        num2str( nu(ii), '%3.0f'), ' degrees of freedom']);
    legend( {'Edgeworth','Real Cdf'}, 'location', 'Best');
    hold off
    
end