function g = EdgeworthPdf( y, kappa )
% Edgeworth  expansion of a the density of a  distribution function F
%
% Input
%        y: point of evalation of the approximation;
%        kappa: first six cimulants.
%
% Output
%        g: Edgeworth expansion of f at point y.
%

n       = length(y);
mu      = kappa(1);
sigma   = sqrt(kappa(2));

z = ( y - mu ) / sigma;

for j = 1:4
    gam(j) = kappa(j+2) / sigma^(j+2);
end

for j = 1:n
    x = z(j);
    p1 = 1 + (gam(1)/6)* H(3,x) +  (gam(2)/24)* H(4,x) + (gam(1)^2/72)*H(6,x) ;
    p11 = + (gam(3)/120)*H(5,x) + (gam(1)*gam(2)/144)* H(7,x);
    
    p2 = (gam(1)^3 /1296)* H(9,x) + (gam(4)/720)* H(6,x);
    p3 = (gam(2)^2/1152)* H(8,x) +(gam(1)*gam(3)/720)* H(8,x);
    p4 = (gam(1)^2*gam(2)/1728)*H(10,x) + (gam(1)^4/31104)* H(12,x) ;
    g(j) =  (exp(-x^2/2)/sqrt(2*pi)).*(p1+p11+p2+p3+p4)/sigma;
end

end

function v = H(k,x)
% Polynomials related to Hermite polynomials and appearing in nthe
% Edgeworth and Cornish-Fisher expansions.
%
%  Input: k: order of the polynomial

order = (0:1:floor( 0.5 * k ))';

v = sum(  (-1).^order .* factorial( k ) .* x.^(k-2*order) ./...
    ( 2.^order .* factorial(order) .* factorial( k-2*order ) ) );

end