function [Edf, pts, EdfMin, EdfMax] = EstCdf( x, cont , graph )
%  Estimation of the distribution function
%  and construction of a 95 percent confidence band
%
%  Input: x: iid sample (n x 1 vector);
%         cont: 1 if the Edf is assumed continuous (default), 0 otherwise;
%         graph: 1 if graph is needed, 0 otherwise (default).
%
% output: Edf: Estimated distribution function at the x;
%         FMin: 95% level lower bound of the confidence band;
%         FMax: 95% level upper bound of the confidence band.

%% Printed output

n = length(x);

Edf = zeros(n,1);

if nargin < 2
    cont = 1;
    graph = 0;
elseif nargin < 3
    graph = 0;
end

if cont
    pts = sort( x );
    Edf = (1:n)' / n;
else
    
    pts = x;
    
    for i = 1:n
        Edf(i) = mean ( (x<= x(i)) );
    end
    
end

% 1.358 corresponds to the 95% quantile of the K-S limiting distribution
EdfMin = Edf - 1.358 / sqrt(n);  
EdfMax = Edf + 1.358 / sqrt(n);

%% Printed output
if(graph)
figure
plot(pts,Edf,'b-');
hold on
plot(pts,EdfMin,'k--');
plot(pts,EdfMax,'k-.');
hold off
title('Empirical distribution function and 95% uniform band')
legend({'Empirical','Lower bound', 'Upper bound'}, 'location', 'best' );
end
