function  [ES, ES_Error] = EstES(x,p)
%  Estimation of the quantile of order p (VaR(p) where x are losses)
%
% Input
%         x: iid sample (n x 1 vector);
%         p: orders (in fraction) for the quantile to be estimated 
%            ( d x 1 vector).
%
% Output
%         Var: Estimated quantiles;
%         ES_Error: 95% level estimation error using the density method;
%
% Example of application: 
% [ES, ES_error] = EstES(x,[0.95;0.99;0.999])

n  = length(x);

X  = sort(x);

d = length(p);

VaR = X( floor( n * p ) );

Z = zeros(n,d);

for j = 1:d
    Z(:,j) = max( 0, x - VaR(j) ) / ( 1 - p(j) );
end

ES = VaR + mean( Z )';

ES_Error = ( 1.96*std(Z)/sqrt(n))';

 %% Printed output 

fprintf('\nLevel             ES            Error\n')
for j = 1:d
    fprintf(' %2.2f       %7f           %7f               \n', 100 * p(j), ES(j), ES_Error(j) )
end