function  [Omega, errorOmega, Gbar, errorG] = EstOmega( x, r )
%  Estimation of the Omega ratio for several assets
%
%  Input
%   x: returns ( n x d);
%   r: short-term interest rate.
%
% Output
%    omega: Estimation of Omega ratios;
%    error: 95% CI errors for the estimation

Y = max(0,x-r);
Z = max(0,r-x);
s1 = std(Y);
s2 = std(Z);
mu1 = mean(Y);
mu2 = mean(Z);

n = size( x, 1 );

Omega = mu1 ./ mu2;
Gbar  = mu1 ./ ( mu1 + mu2 );

mu1v = repmat(mu1, n, 1);
mu2v = repmat(mu2, n, 1);
U    = ( Y - repmat(Omega,n,1) .* Z ) ./ mu2v;
V    = ( repmat(Gbar,n,1) .* ( Y + Z ) -Y ) ./ ( mu1v + mu2v );

% 95% CI error
errorOmega  = 1.96 * std(U) / sqrt(n);
errorG      = 1.96 * std(V) / sqrt(n);