function [sh, error] = EstSharpe( x, r )
%  Estimation of the Sharpe ratio of several assets.
%
%  Input 
%   x: returns ( n x d);
%   r: short-time interest rate.
%
% Output
%   sh: Estimation of Sharpe's ratios;
%   error: 95% CI errors for the estimation

[n,d] = size(x);

mu  = mean(x);
s   = std(x);
sh  = (mu-r)./s;
g1  = skewness(x);
g2  = kurtosis(x);

shv = repmat(sh,n,1);

Z = ( x - repmat( mu, n, 1 ) )./ repmat( s, n, 1);

W = Z - 0.5 * repmat( sh, n, 1).* ( Z.^2 - 1 );

% 95% CI error 
error = 1.96*std( W ) / sqrt( n );  