function  [so, error] = EstSortino( x, r )
%  Estimation of Sortino  ratio  for several assets.
%
%  Input
%   x: returns ( n x d);
%   r: short-time interest rate.
%
% Output
%    so: Estimation of Sortino ratio;
%    error: 95% CI errors for the estimation.

[n,d] = size(x);

mu = mean(x);
Z  = max(0, r - x );
D  = sqrt( mean( Z.^2 ) );

so = (mu-r)./D;

Dv = repmat( D, n, 1);
W =  ( x - repmat( mu, n, 1 ) ) ./ Dv - repmat( so, n, 1).*...
    ( Z .^ 2 - Dv .^ 2 ) ./ ( 2 * Dv .^2 );

% 95% CI error
error = 1.96 * std(W) / sqrt(n);