function [Fhat, F, xnew] = SaddleNChi2Cdf(x,nu,D)
% Computes the saddlepoint approximation of the distribution function of 
% a non-central chi-square with nu degrees of freedom and non-centrality 
% parameter D.
%
% Cumulant generating function: (tD)/(1-2t)-(nu/2)log(1-2t).
%
% Input 
%   x: vector of points;
%   nu: degrees of freedom;
%   D: non-centrality parameter >= 0.
%  
%  Output
%    Fhat: saddlepoint approximation of the density;
%    F   : real density.
%

z = 0.5*(nu+sqrt(nu^2+4*D*x))./x;  % z = 1-2t

t = .5*(1-z); % saddlepoints

L = t.*x + 0.5*nu*log(z)-D*t./z;

K2 = 4*D./z.^3 + 2*nu./z.^2;

u = t.*sqrt(K2);
w = sign(t).*sqrt(2*L);

n = length(x);


ind0 = (1:n)';

z1 = (u~=0);
z2 = (u==0);
ind1 = ind0.*z1;
ind2 = ind0.*(u==0);
u1 = u(ind1>0);
w1 = w(ind1>0);

  sig = sqrt(2*(nu+2*D)); 

Fhat = normcdf(w1) + normpdf(w1).* ( 1./w1 - 1./u1 );

% Bad approximation! Better to interpolate!
%Fhat(ind2>0) = 0.5 + 8*(nu+3*D)/(6*sqrt(2*pi)*sig^2);

xnew = x(ind1>0);
F = ncx2cdf(xnew,nu,D);


