function [fhat, f] = SaddleNChi2Pdf(x,nu,D)
% Computes the saddlepoint approximation of the density of a non-central
% chi-square with nu degrees of freedom and non-centrality parameter D.
%
% Cumulant generating function: (tD)/(1-2t)-(nu/2)log(1-2t).
%
% Input 
%   x: vector of points;
%   nu: degrees of freedom;
%   D: non-centrality parameter >= 0.
%  
%  Output
%    fhat: saddlepoint approximation of the density;
%    f   : real density.
%

z = 0.5*(nu+sqrt(nu^2+4*D*x))./x;  % z = 1-2t

t = .5*(1-z); % saddlepoints

L = t.*x + 0.5*nu*log(z)-D*t./z;

K2 = 4*D./z.^3 + 2*nu./z.^2;

fhat = exp(-L)./sqrt(K2)/sqrt(2*pi);

f = ncx2pdf(x,nu,D);


