function r = SimCIR( alpha, beta, sigma, r0, n, h)
% Simulation of a Feller process satisfying
% dr = alpha(beta-r)dt + sigma sqrt(r) dW   
%
%  Input
%    r0: initial value;
%     n: number of values;
%     h: time step between observations.
%
%   Output
%      r: annual rate
%
%   Output
%      r: annual rate in percent
%
% r = SimCIR(0.5,2.55,0.365,2.55,720,1/360);

% precomputations




sigmaSquared = sigma^2;
nu           = 4 * alpha * beta / sigmaSquared 
phi          = exp( - alpha * h );
omega        = sigmaSquared * ( 1-phi )  / ( 4 * alpha );

r    = zeros(n+1,1);
r(1) = r0;

addpath( '../ChapterA')
for t = 2:n+1
    x = r(t-1) / omega;
    D = x * phi;  % non-centrality parameter
    r(t) = omega * SimNChi2( nu, D );
   % r(t) = omega * ncx2rnd( nu, D );
end
rmpath( '../ChapterA')

figure
plot(r)
title(['CIR model for the spot rate with   \alpha = ',num2str(alpha),', \beta = ',num2str(beta),', \sigma = ',num2str(sigma),', \nu = ',num2str(nu)]);