function r = SimVasicek( alpha, beta, sigma, r0, n, h)
% Simulation of a Ornstein-Uhlenbeck process satisfying
%
%    dr = alpha(beta-r)dt + sigma  dW,
%
% observed at periods h, 2h, ..., nh.
%
%  Input
%    r0: initial value;
%     n: number of values;
%     h: time step between observations.
%
%   Output
%      r: annual rate
%
% r = SimVasicek(0.5,2.55,0.365,2.55,360,1/360);

phi = exp( - alpha * h);
vol = sigma * sqrt( ( 1 - phi^2 ) / ( 2 * alpha ) );

r = zeros(n+1,1);

r(1) = r0;

for i = 2:n+1
    r(i)  = beta + phi * ( r(i-1) - beta ) + vol * randn();
end

t = (1:n)*h;

t = [ 0;t'];

plot( t, r )
title(['OU model for the spot rate with  \alpha = ',num2str(alpha),...
         ', \beta = ',num2str(beta), ', \sigma = ',num2str(sigma)]);
     
     
    