function [kappa, V, W] = EstCumulants( x )
% Estimation of the first 6 cumulants of of a sample of i.i.d observations
%
% Input
%       x: i.i.d. observations (n x 1 vector)
%
% Output
%      kappa: first six cumulants;
%          V: covariance matrix of errors;
%          W: pseudo-observations.
%
%
m = zeros(6,1);

m(1) = mean(x);

for j = 2:6
    m(j) = moment(x, j);
end

kappa = zeros(6,1);

kappa(1) = m(1); 
kappa(2) = m(2); 
kappa(3) = m(3);
kappa(4) = m(4) - 3 * kappa(2)^2;
kappa(5) = m(5) - 10 * kappa(2) * kappa(3);
kappa(6) = m(6) - 15 * kappa(2) * kappa(3) - 10 * kappa(3)^2 - 15 * kappa(2)^3;

%% centered variables
Z1 = x - m(1);
Z2 = ( x - m(1) ) .^ 2;
Z3 = ( x - m(1) ) .^ 3;
Z4 = ( x - m(1) ) .^ 4;
Z5 = ( x - m(1) ) .^ 5;
Z6 = ( x - m(1) ) .^ 6;


%% pseudo-observations
W1 = Z1; 
W2 = Z2;
W3 = Z3 - 3 * kappa(2) * Z1; 
W4 = Z4 - 4 * kappa(3) * Z1 - 6 * kappa(2) * Z2;
W5 = Z5 - 5 * Z1 * ( kappa(4) - 3 * kappa(3)^2 )-10 * Z2 * kappa(3) - 10 * Z3 * kappa(2); 
W6 = Z6 - 6 * Z1 * ( kappa(5) - 10 * kappa(3) * kappa(2) ) - 15 * Z2 * ( kappa(4) - 3 * kappa(3)^2 )...
    - 20 * Z3 * kappa(3) - 15 * Z4 * kappa(2);

W = [W1 W2 W3 W4 W5 W6];

%% covariance
V = cov(W);