function  [f] = MertonPdf(x,param,h,graph)

%%
if nargin < 4
    graph = 0;
end

%%
mu     = param(1);
sigma  = param(2);
lambda = param(3);
gamma  = param(4);
delta  = param(5);


mu1             = mu * h;
sig1            = sigma * sqrt( h );
jumpIntensity   = lambda * h;
kappa           = exp( gamma + delta^2 / 2 ) - 1;

a =     mu1 - jumpIntensity * kappa - 0.5*sig1^2; 

%%
K = 1;
err =  Error(sig1,K,jumpIntensity,delta);

while (err > 1E-10)
    K = K+1;
    err =  Error(sig1,K,jumpIntensity,delta);
end

%%
tt = (0:K);

prob = poisspdf(tt,jumpIntensity);


mu2 = a+tt*gamma;
sig2 = sqrt(sig1^2+tt*delta^2);


m = length(x);

xmat = repmat(x,1,(K+1));
mumat = repmat(mu2,m,1);
sigmat = repmat(sig2,m,1);

z = (xmat-mumat) ./ sigmat;

P = exp(-0.5*z.^2) ./ sigmat /sqrt(2*pi);

f = P*prob';
%%
if(graph)
    figure
    plot(x,f);
end
end
%%
function [err] = Error(sig1,k,jumpIntensity,delta)

err = (1-poisscdf(k,jumpIntensity))/sqrt(2*pi)/sqrt(sig1^2+k*delta^2);
end

