function [y, t] = SimCompoundPoisson( lambda, delta, p, n)
% Generates a compound Poisson process with jumps  delta
% with probability p and 1-p respectively.
% The process is observed at periods 1/n, 2/n, ...,1.
%
%  Input
%       lambda: intensity of the Poisson process;
%            p: probability of a positive jump;
%            n: number of periods.
%
%  Output
%        y: process observed at t(k) = k/n;
%        t: observation times.

V = poissrnd( lambda / n, [n,1] );

x = zeros(n,1);
for i = 1:n
    x(i) = delta * ( 2 * binornd( V(i) , p ) - V(i) );
end

t = (1:1:n)' / n;

y = cumsum(x);