function [y, t] = SimLevyGamma( alpha, beta, n)
% Generates a Gamma process with X(t) ~ Gamma( alpha t, beta).
% The process is observed at periods 1/n, 2/n, ...,1.
%
%  Input
%       alpha: shape parameter of the jumps,
%       beta : scale parameter,
%           n: number of periods.
%
%  Output
%        y: process observed at t(k) = k/n,
%        t: observation times

x = gamrnd( alpha / n, beta, [n, 1] );

t = (1:1:n)' / n;

y = cumsum(x);