function [y, t] = SimLevyGammaStd( alpha, n )
% Generates a standardized Gamma process with
% X(t) + alpha beta t ~ gamma(alpha t, beta), alpha beta^2 = 1.
% The process is observed at periods 1/n, 2/n, ...,1.
%
%  Input
%       alpha: shape parameter of the jumps,
%       beta : scale parameter,
%           n: number of periods.
%
%  Output
%        y: process observed at t(k) = k/n,
%        t: observation times

beta = 1 / sqrt( alpha );

x = gamrnd( alpha / n, beta, [n, 1] ) - alpha * beta / n;

t = (1:1:n)' / n;

y = cumsum(x);