function [S,f,stats] = SimVG(param, n, h )
% Simulation of a path of Variance Gamma process : theta V + sqrt(V) Z
% where V ~ Gamma(alpha,beta).
%
% Input
%       param: alpha >0, beta >0, theta (annual parameters);
%       n: number of observations;
%       h: time between observations (default h =1/252 corresponding to
%       daily onservations).
%
%  Output
%       S: prices, with S(0) = 100.
%
% Example:
%   S = SimVG([470,0.0002,11],500)

if nargin < 3
    h = 1/252;
end

mu       = param(1);
sigma    = param(2);
alpha    = param(3);

% adjusted parameters
alpha1   = alpha*h;
mu1      = mu*h;
sigma1   = sigma*sqrt(h);


alpha1 = alpha*h;

V = gamrnd(alpha1,1,n,1)/alpha1;

X = mu1*V+ sigma1 * sqrt(V) .* randn(n,1);

S = 100 * exp( cumsum( X ) );

figure
plot( S );
title({['Variance Gamma proces with \mu = ',num2str(mu),...
    ', sigma = ', num2str(sigma), ', \alpha = ', num2str(alpha)]});

x = sort(X);

[f, stats] = VGPdf(x,param,h,1);

    
names = {'Mean      ','Volatility','Skewness  ','Kurtosis  '};
fprintf('\n  Theoretical and estimated moments of the returns\n');
moments = zeros(4,1);

moments(1) = mean(x)/h; 
moments(2) = std(x)/sqrt(h);
moments(3) = skewness(x)*sqrt(h);
moments(4) = 3+(kurtosis(x)-3)*h;


for j=1:4
    fprintf('%10s :  %4.4f  %4.4f\n',names{j},stats(j),moments(j));
end
