function  [f, stats] = VGPdf(x,param,h,graph)
% Density of  VG(1) = theta*V+ sqrt(V)*Z, V ~ Gamma(alpha,beta).

%%
if nargin < 4
    graph = 0;
end

%%

mu       = param(1);
sigma    = param(2);
alpha    = param(3);

% adjusted parameters
alpha1   = alpha*h;
mu1      = mu*h;
sigma1   = sigma*sqrt(h);

beta     = sigma^2/alpha;
theta    = mu/sigma^2;



c1 = sqrt(theta^2+2/beta);
c2 = alpha1-0.5;
y = abs(x)/c1;

z1 = gampdf(y,alpha1,beta);
z2 = besselk(c2,y*c1^2);

f = z1 .* z2 .*sqrt(2*y/pi) .* exp(y*(theta*c1+1/beta));

%% first 4 cumulants
stats    = zeros(4,1);

nu       = 1/alpha;
v        = sigma^2 + nu*mu^2;
stats(1) = mu;
stats(2) = sqrt(v);
stats(3) = mu*nu*(sigma^2 + 2*v)/(stats(2))^3;
stats(4) = 3* (1 + 2*nu - nu * sigma^4/v^2 );


if(graph)
    stats
    figure
    plot(x,f,'k');
end