% This folder contains Matlab functions, scripts and data sets that are 
% used in Chapter 6 of
%
%        'Statistical Methods for Financial Engineering'. 
%
% Here is a quick description.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%                 FUNCTIONS AND SCRIPTS
%
% SimJumpDiffKou     : Simulation of asset prices under Kou model.
%
% SimJumpDiffMerton  : Simulation of asset prices under Merton model.
%
% SimJumpDiffWSG     : Simulation of asset prices under a weighted-symmetric 
%                      Gaussian model.
%
% SimLevyGamma       : Simulation of a trajectory of the Gamma process.
%
% SimLevyGammaStd    : Simulation of a trajectory of a standardized gamma
%                      process.
%
% SimPoissonJumps    : Simulation over a given time interval of the jumping 
%                      times of a Poisson process.
%
% SimCompoundPoisson : Simulation of a trajectory of a compound Poisson 
%                      process.
%
% SimVG              : Simulation of asset prices under the Variance Gamma
%                      model.
% 
% DemoCompoundPoisson: Script illustrating the weak convergence to Brownian 
%                      motion for a compound Levy process.
%
% DemoVG             : Script illustrating the weak convergence to Brownian 
%                      motion for a Variance Gamma process.
%
% DemoLevyGammaStd   : Script illustrating the weak convergence to Brownian 
%                      motion for a standardized Gamma process.
%
% EstMerton          : Maximum likelihood estimation of the parameters of 
%                      the Merton model.
%
% EstMertonCum       : Cumulant matching estimation of the parameters of 
%                      the Merton model.
%
% EstCumulants       : Estimation of the cumulants of a sample.
%
% EstVG              : Maximum likelihood estimation of the parameters of 
%                      the Variance Gamma model.
%
% EstVGMean          : Combined estimation of the parameters of the 
%                      Variance Gamma model.
%
% MertonCdf          : Distribution function of the Merton model.
%
% MertonPdf          : Density function of the Merton model.
%
% VGPdf              : Density function of the Variance Gamma model.
%
% SolEx              : Solutions of selected exercises.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%                 DATA SETS
%
% DataMerton     : Data simulated under the Merton model with parameters
%                  [0.08; 0.22; 100; 0.05; 0.005];
%
% DataVG         : Data simulated under the Variance Gamma model with 
%                  parameters [0.15; 0.5 1000];
%


