function DemoGARCH( mu, omega, alpha, beta, n)

% memory allocation
eps         = randn( n, 1 );
h           = zeros( n, 2 );
returns     = zeros( n, 2 );

% initialize time series
h(1,:)          = [0 0.1];
returns(1,:)    = [0 0.01];

for i = 2:n
    
    h(i,:) = omega + beta * h(i-1,:) + alpha * ( returns(i-1,:) - mu ).^2;
    
    returns(i,:) = mu + sqrt( h(i,:) ) * eps(i);
    
end

t = 1:1:n;
Prices = 100 * exp( cumsum( returns ) );

subplot(3,1,1); plot( t, Prices );
legend({'S_x','S_y'}, 'location', 'best');
title({'GARCH(1,1): Prices S_x and S_y starting from 100';['Parameters: \mu = ' num2str(mu) ' , \omega = ' num2str(omega) ' , \alpha= ' num2str(alpha) ' , \beta = ' num2str(beta)]});

subplot(3,1,2); plot( t, returns );
title(['GARCH(1,1): Returns x and y starting from x_0 = ' num2str(returns(1,1)) ' and y_0 = ' num2str(returns(1,2))]);
legend( {'x','y'}, 'location', 'best');

subplot(3,1,3); plot(t, sqrt( h ) );
title(['GARCH(1,1): Conditional volatilities \sigma and v starting from h_1 = ' num2str(h(1,1)) ' and v_1 = ' num2str(h(1,2))] );
legend({'\sigma', 'v'}, 'location', 'best');

fprintf('\n')
fprintf('\n Initial values:\n')
fprintf('x(1) = %f, h(1) = %f\n', returns(1,1), h(1,1))
fprintf('y(1)= %f, v(1) = %f \n\n' , returns(1,2), h(1,2))