function DemoBondPortfolio
clear all; close all; clc
% Simulation of losses of a portfolio of bonds for several copula models,
% using CrediMetrics approach

P= [ 90.81 , 8.33  , 0.68  , 0.06  , 0.12  , 0     , 0    , 0;
    0.70  , 90.65 , 7.79  , 0.64  , 0.06  , 0.14  , 0.02 , 0;
    0.09  , 2.27  , 91.05 , 5.52  , 0.74  , 0.26  , 0.01 , 0.06;
    0.02  , 0.33  , 5.95  , 86.93 , 5.30  , 1.17  , 0.12 , 0.18;
    0.03  , 0.14  , 0.67  , 7.73  , 80.53 , 8.84  , 1.00 , 1.06;
    0.01     , 0.11  , 0.24  , 0.43  , 6.48  , 83.46 , 4.07 , 5.20;
    0.22  , 0     , 0.22  , 1.30  , 2.38  , 11.24 , 64.86 , 19.78;
    0,0,0,0,0,0,0,100]/100;

P= [ 88   , 8     , 3  , 1     , 0      , 0     , 0    , 0;
    1     , 88    , 6     , 4  , 1      , 0     , 0    , 0;
    0.5   , 2     , 90    , 6     , 1      , 0.5     , 0     , 0;
    0     , 0     , 6     , 87    , 6      , 1     , 0    , 0;
    0     , 0     ,0      , 8     , 81     , 10     , 1     , 0;
    0     , 0     ,0      , 0.5    ,  3.5      , 82    , 8    ,   6;
    0     , 0     ,0      , 0.5     , 2.5   , 10    , 66    , 21;
    0,0,0,0,0,0,0,100]/100;

F = cumsum( P' )';

%% Recovery rates
Z = [53.80, (53.80+51.13)/2,51.13,(51.13+38.52)/2,38.52,(38.52+17.09)/2,17.09]'/100;

%% Face value
face = 100;
rate = 0.02;
beta = [ 1/(1+rate), 1/(1+rate)^2, 1/(1+rate)^3,1/(1+rate)^4];

Q1 = P(1:7,1:7);
Q0 = eye(7,7);
Q2 = Q1 * Q1;
Q3 = Q1 * Q2;
Q4 = Q1 * Q3;
P0 = eye(8,8);
P2 = P * P;
P3 = P * P2;
P4 = P3 * P;
D1 = P(1:7,8);
D2 = P2(1:7,8);
D3 = P3(1:7,8);
D4 = P4(1:7,8);

V0 = face * beta(4) * ( (1 - D4) +  (Q0 + Q1 + Q2 + Q3) * Z .* D1 );
V1 = face * beta(3) * ( (1 - D3) +  (Q0 + Q1 + Q2) * Z .* D1 );
V2 = face * beta(2) * ( (1 - D2) +  (Q0 + Q1) * Z .* D1 );
V3=  face * beta(1) * ( (1 - D1) +   Q0 * Z .* D1 );

V0 = [V0; 0];
V1 = [V1; 0];
V2 = [V2; 0];
V3 = [V3; 0];

V = [V0';V1';V2';V3'];

tt = [ 0 1 2 3]';

figure
plot(tt,V(:,4),'-');
hold on
plot(tt,V(:,5),'r:');
hold on
plot(tt,V(:,6),'g-.')
hold on
plot(tt,V(:,7),'k--')
legend( {'BBB','BB','B','CCC'}, 'location', 'best' );

%% Monte Carlo simulations
N = 100000;

%% Independence copula

X0  = [6;7;7;7;7;1;1;1;1;2;2;2;2;3;3;3;3;4;4;4;4;5;5;5;5;6;6;6];
d   = length(X0);

Loss_ind = zeros(d,N);
Val0     = V0( X0 );

for i = 1:N
    U               = rand(d,1);
    X1              = GenMarkovOneStep( P, X0, U );
    Loss_ind(:,i)   = Val0 - beta(1) * V1( X1 ) ;
end

X_ind    = sort( Loss_ind' );
Port_ind = sort( ( sum( Loss_ind ) )' );

Fn = (1:1:N)'/N;

figure
stairs( X_ind(:,1), Fn, 'b-')
title('Estimation of the distribution function of the losses for a bond rated B')

figure
stairs( X_ind(:,2), Fn, 'b-')
title('Estimation of the distribution function of the losses for a bond rated CCC')

figure
stairs( X_ind(:,1), Fn, 'b-')
hold on
stairs( X_ind(:,2), Fn, 'r:')
title('Comparison of the distribution function of the losses of two bonds')
legend( {'B','CCC'}, 'location', 'best' );

figure
stairs( Port_ind, Fn, 'b-')
title('Estimation of the distribution function of the losses under independence')

%% Gaussian and Student copulae

% parameters
tau     = 0.9;
rho     = sin( 0.5 * pi * tau );
Sigma   = rho * ones(d,d) + (1-rho) * eye(d);
a       = chol( Sigma );
nu      = 4.5;

% memory allocation
Loss_nor = zeros(d,N);
Loss_T   = zeros(d,N);

for i = 1:N
    Y   = sqrt( chi2rnd( nu, 1, 1 ) / nu );
    U0  = a' * randn(d,1);
    T   = U0 / Y;
    U   = normcdf( U0 );
    UT  = tcdf( T, nu );
    X1  = GenMarkovOneStep( P, X0, U);
    X2  = GenMarkovOneStep( P, X0, UT);
    Loss_nor(:,i)   =  Val0 - beta(1) * V1( X1 );
    Loss_T(:,i)     =  Val0 - beta(1) * V1( X2 );
end

X_nor    = sort( Loss_nor' );
X_T      = sort( Loss_T' );
Port_nor = sort( ( sum( Loss_nor ) )' );
Port_T   = sort( ( sum( Loss_T ) )' );

figure
stairs( Port_ind, Fn, 'b-')
hold on
stairs( Port_nor, Fn, 'r:')
title('Independence, Gaussian copula (\rho=.9)')
legend( {'Independence', 'Gaussian copula'}, 'location', 'best' );

figure
stairs( Port_nor, Fn, 'b-')
hold on
stairs( Port_T, Fn, 'r:')
title('Gaussian copula (\rho=.9) , Student copula(\nu=4.5,\rho=0.9)')
legend( {'Gaussian copula','Student copula'}, 'location', 'best' );

%%  Clayton copula

% parameter
tau     = 0.9;
theta   = 2 * tau / ( 1 - tau );

% memory allocation
Loss_C = zeros(d,N);

for i = 1:N
    U0 = - log( rand(d,1) );  %%%% Exponential variates
    Y  = gamrnd( 1 / theta, 1 , 1 , 1 );
    U1 = U0 / Y;
    U  = ( 1 + U1 ) .^ ( - 1 / theta );
    X1 = GenMarkovOneStep( P, X0, U);
    Loss_C(:,i) =  Val0 - beta(1) * V1( X1 );
end

Port_C = sort( ( sum( Loss_C ) )' );

figure
stairs( Port_ind, Fn, 'b-')
hold on
stairs( Port_C, Fn, 'r:')
title('Independence, Clayton copula (\theta =18)')
legend({'Independence', 'Clayton copula'}, 'location', 'best');

figure
stairs( Port_nor, Fn, 'b-')
hold on
stairs( Port_C, Fn, 'r:')
title('Gaussian copula (\rho=.9) , Clayton copula (\theta =18)')
legend({'Gaussian copula','Clayton copula'}, 'location', 'best');

%% Gumbel copula

% parameter
tau     = 0.9;
theta   = 1 - tau;
a       = 1 / theta;

U0 = - log( rand(d,N) );  %%%% Exponential variates
U1 = pi * rand(N,1);
U2 = - log( rand(N,1) );
Y1 = sin(U1) .^(-a);
Y2 = sin( theta * U1 );
Y3 = sin( ( 1 - theta ) * U1 );
Y4 = Y3 ./ U2;
Y5 = Y4 .^ ( a - 1 );
Y6 = Y1 .* Y2;
Y  = Y5 .* Y6;  % Stable law of parameter theta

for i = 1:N
    U(:,i) = U0(:,i) / Y(i);
end

U3  = U .^ theta;
U   = exp( - U3 );

Loss_G = zeros(d,N);

for i = 1:N
    X1          = GenMarkovOneStep( P, X0, U(:,i) );
    Loss_G(:,i) = Val0 - beta(1) * V1( X1 );
end

Port_G = sort( ( sum( Loss_G ) )' );

figure
stairs( Port_ind, Fn, 'b-')
hold on
stairs( Port_G, Fn, 'r:')
title('Independence, Gumbel copula (\theta =0.1)')
legend({'Independence', 'Gumbel copula '}, 'location', 'best');

figure
stairs( Port_nor, Fn, 'b-')
hold on
stairs( Port_G, Fn, 'r:')
title('Gaussian copula (\rho=.9) , Gumbel copula (\theta =0.1))')
legend({'Gaussian copula','Gumbel copula'}, 'location', 'best');

%% Frchet mixture copula

% Frechet with probability p, ind with prob 1-p.
tau = 0.9; % = p(p+2)/3
p   = sqrt(1+3*tau)-1;

% memory allocation
Loss_F = zeros(d,N);

for i = 1:N
    U0 = rand;
    if U0 < p
        U = rand * ones(d,1);
    else
        U = rand(d,1);
    end
    X1          = GenMarkovOneStep( P, X0, U);
    Loss_F(:,i) = Val0 - beta(1) * V1( X1 );
end

Port_F = sort( ( sum( Loss_F ) )' );

figure
stairs( Port_ind, Fn, 'b-')
hold on
stairs( Port_F, Fn, 'r:')
title('Independence, Frchet mixture copula (p = .9235)')
legend({'Independence', 'Frchet mixture copula '}, 'location', 'best');

figure
stairs( Port_nor, Fn, 'b-')
hold on
stairs( Port_F, Fn, 'r:')
title('Gaussian copula (\rho=.9) , Frchet mixture copula (p = .9235)')
legend({'Gaussian copula','Frchet mixture copula'}, 'location', 'best');

%% Var
VaR= prctile( [Port_ind, Port_nor, Port_T, Port_C, Port_G, Port_F], [95,99,99.9] );

fprintf('\n\n\n\n VaR   Ind     Gaussian    Student   Clayton    Gumbel     Frchet \n\n');
fprintf('  95   %4.2f   %4.2f     %4.2f    %4.2f     %4.2f     %4.2f \n',VaR(1,:));
fprintf('  99   %4.2f   %4.2f     %4.2f    %4.2f     %4.2f     %4.2f \n',VaR(2,:));
fprintf('99.9   %4.2f   %4.2f     %4.2f    %4.2f     %4.2f     %4.2f \n\n\n\n',VaR(3,:));
end

%%
function X1 = GenMarkovOneStep( P, X0, u)
% Generates X1 starting from X0 for a d-dimensional Markov chain with 
% marginal matrix transition P and random vector U in [0,1]^d. 
% 
% The state space is {1,2, ..., m}.

d = length( X0 );
F = cumsum( P, 2 );
d = length( X0 );
m = size(P, 1);

for i = 1:d;
    p = u(i);
    y = X0(i);
    k=m;
    while   k>0 && p < F(y,k)
        k = k-1;
    end
    X1(i) = k+1;
end

end