%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Estimation of the parameters for copula models of Apple and Microsoft
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%
addpath(genpath('../')); 

load('ApplePrices.mat');
load('MicrosoftPrices.mat');

%% Lok:returns

X1 = diff(log(ApplePrices)); 

X2 = diff(log(MicrosoftPrices)); 

figure
plot(X1)
title('Returns of Apple')
autocorr(X1,50);


figure
plot(X2)
title('Returns of Microsoft')
autocorr(X2,50);

n = length(X1);


figure
plot(X1,'b-')
hold on
plot(X2,'k:')
title('Returns of Apple and Microsoft');
 h = legend('Apple','Microsoft',4);




figure
scatter(X1,X2,'.')
title('Pairs of returns of Apple and Microsoft')

%%  

data = [X1,X2];

out = EstDep(data);

figure
scatter(out.pseudo(:,1),out.pseudo(:,2),'.')
title('Pairs of pseudo-observations')


 t = sort(out.pseudo(:,3),1);
 
 
 %% Change point
 
 tic
 [KSCP1,PvalueKSCP1] = TestChangePoint(X1,1000);
 [KSCP2,PvalueKSCP2] = TestChangePoint(X2,1000);
 toc
 %% Serial independence
 
 outSI1 = SerIndGRTest(X1,6,1000,.95,1);
 
 outSI2 = SerIndGRTest(X2,6,1000,.95,1);
 %% Independence 
outK = IndKendallTest(data,1000,1);

outC = IndGRTest(data,1000,.95,1);

%%  

[param1, innovations1, sigma1, residuals1, error1, cov_est1]  = EstGARCHGED(X1,1,1);
[CVMGED1,KSGED1,PvalueCVMGED1,PvalueKSGED1, KS95GED1, pseudosGED1] = GofGARCHGED(residuals1, X1, param1.C, param1.K, param1.GARCH, param1.ARCH, param1.Shape, 1000, 1)
[param2, innovations2, sigma2, residuals2, error2, cov_est2]   = EstGARCHGED(X2,1,1);
[CVMGED2,KSGED2,PvalueCVMGED2,PvalueKSGED2, KS95GED2, pseudosGED2] = GofGARCHGED(residuals2, X2, param2.C, param2.K, param2.GARCH, param2.ARCH, param2.Shape, 1000, 1)

%%
figure
plot(residuals1)
title('Residuals of Apple')
autocorr(residuals1,50);


figure
plot(residuals2)
title('Residuals of Microsoft')
autocorr(residuals2,50);

 

%%  Change point for residuals
 
tic
 [KSCP1,PvalueKSCP1] = TestChangePoint(residuals1,10000);
 [KSCP2,PvalueKSCP2] = TestChangePoint(residuals2,10000);
 
 toc
%%
datares = [residuals1 residuals2];

%% Change point test for the copula

tic
[KSCPCopula, PvalueKSCPCopula, tau] = TestChangePointCopula(datares, 10000, 1);
toc
%%

out_res = EstDep(datares);

figure
scatter(out_res.pseudo(:,1),out_res.pseudo(:,2),'.')
title('Pairs of pseudo-observations for the residuals')


 t = sort(out_res.pseudo(:,3),1);

outK_res = IndKendallTest(datares,1000,1);
outC_res = IndGRTest(datares,1000,.95,1);


save('ExAppleMicrosoft')
%%
%Goodness-of-fit tests based on the Kendall function are not available for
%distribution
% addpath('../../../../MyMatlab/Copulas')
% 
% %% Clayton 
%  
%   [theta_C, CVM_C, KS_C, Pvalue_C, VaR_C] = K_gof_archi(datares,1, 1, 1000)
%  
%  [K_C] = K_cdf_m(t,theta_C,1,2);
%  figure
%  plot(outK_res.Kn(:,2),outK_res.Kn(:,1))
%  hold on
%  plot(t,K_C,'k:')
%  hold on
%  plot(t,K_C+VaR_C(2)/sqrt(n),'r:')
%  hold on
%  plot(t,K_C-VaR_C(2)/sqrt(n),'r:')
%  title('95% confidence band about K for Clayton family');
%  h = legend('K_n','K_{Clayton}',4);
%  
%  %% Frank 
%  
%  fprintf('Results for Frank family')
%  [theta_F, CVM_F, KS_F, Pvalue_F, VaR_F] = K_gof_archi(datares,2, 1, 1000)
%  
%  [K_F] = K_cdf_m(t,theta_F,2,2);
%  figure
%  plot(outK.Kn(:,2),outK.Kn(:,1))
%  hold on
%  plot(t,K_F,'k:')
%  hold on
%  plot(t,K_F+VaR_F(2)/sqrt(n),'r:')
%  hold on
%  plot(t,K_F-VaR_F(2)/sqrt(n),'r:')
%  title('95% confidence band about K for Frank family');
%  h = legend('K_n','K_{Frank}',4);
%  
% %% Gumbel 
%  
%  fprintf('Results for Gumbel family')
%  [theta_G, CVM_G, KS_G, Pvalue_G, VaR_G] = K_gof_archi(datares,3, 1, 1000)
%  
%  [K_G] = K_cdf_m(t,theta_G,3,2);
%  figure
%  plot(outK.Kn(:,2),outK.Kn(:,1))
%  hold on
%  plot(t,K_G,'k:')
%  hold on
%  plot(t,K_G+VaR_G(2)/sqrt(n),'r:')
%  hold on
%  plot(t,K_G-VaR_G(2)/sqrt(n),'r:')
%  title('95% confidence band about K for Gumbel family');
%  h = legend('K_n','K_{Gumbel}',4);
%  
%  %% AMH 
%  
%  fprintf('Results for Ali-Mikhail-Haq family')
%  [theta_AMH, CVM_AMH, KS_AMH, Pvalue_AMH, VaR_AMH] = K_gof_archi(datares,4, 1, 1000)
%  
%  [K_AMH] = K_cdf_m(t,theta_AMH,4,2);
%  figure
%  plot(outK.Kn(:,2),outK.Kn(:,1))
%  hold on
%  plot(t,K_AMH,'k:')
%  hold on
%  plot(t,K_AMH+VaR_AMH(2)/sqrt(n),'r:')
%  hold on
%  plot(t,K_AMH-VaR_AMH(2)/sqrt(n),'r:')
%  title('95% confidence band about K for Ali-Mikhail-Haq family');
%  h = legend('K_n','K_{AMH}',4);
  
 
 



 
 
 %% Clayton
 tic
 [paramC,SnBC,PvalueCR,SnSimC,EhatC] =  GofRosenCopula(datares,'Clayton','B',1000);
 toc
  save('ExAppleMicrosoft');
 
  
  %% Student
  tic
  [paramT,SnBTR,PvalueTR,SnSimT,EhatT] = GofRosenCopula(datares,'t','B',1000);
  toc
  save('ExAppleMicrosoft');
  
  %% Gaussian
  tic
  [paramG,SnBGR,PvalueGR,SnSimG,EhatG] = GofRosenCopula(datares,'Gaussian','B',1000);
  toc
  save('ExAppleMicrosoft');
  
  