function Graph3dCopula( x, m )
% 3-d graph of an empirical copula and the associated density.
%
% Input
%       x : data (n x 2),
%       m : number of points on [0,1];

Cop = zeros( m, m );
U = Pseudos(x);
U1  = U(:,1);
U2  = U(:,2);

for i = 1:m
    v = i / m;
    indicatorU2 = ( U2 <= v );
    for j = 1:m
        u        = j / m;
        Cop(i,j) = mean( ( U1 <= u ) .* indicatorU2 );
    end
end

u = (1:m)' / m;

[X,Y] = meshgrid( u, u );
figure
surf( X, Y, Cop );
set( gca, 'xlim', [0 1], 'ylim', [0 1])

[fn,X,Y] = EstPdfCop2d(U1,U2,m);

figure
[C,h] = contour( X, Y, fn );
%set( gca, 'xlim', [0 1], 'ylim', [0 1])

set(h,'ShowText','on','TextStep',get(h,'LevelStep')*2)
colormap cool
end

%%
function [fn,X,Y] = EstPdfCop2d(U1,U2,m)
% Poinwise estimation of the density of a bivariate copula using the 
% Gaussian kernel.
%


n     = length(U1);   
h     = n^(-0.2)/sqrt(12);
u     = (1:m)' / (m+1);
[X,Y] = meshgrid( u, u );
fn    = zeros(m, m );

for i = 1:m
    f1 = normpdf( ( U1 - u(i) ) / h ) / h;
    for j=1:m
        f2 = normpdf( ( U2 - u(j) ) / h ) / h;
        fn(i,j) = mean(  f1 .* f2 );
    end
end


end