function [U,V] = Pseudos(X)
% Compute pseudo-observations (normalized ranks U and associated V) for a 
% sample of i.i.d. random vectors.
%  
% Input 
%        X: data (n x d matrix)
%
% Output:
%        U: Pseudo=observations (normalized ranks),
%        V: Pseudo=observations for Kendall  function.

[n, d]  = size( X );
 V      = zeros( n, 1 );
 U      = zeros( n, d );

for i = 1:n
    
   y = repmat( X(i,:), n, 1);
   z = ones(n,d) .* (X < y);
   V(i) = sum( prod( z, 2) ) / ( n - 1 );
   U( i, : ) = sum( (X <= y)  ) / ( n + 1 ); 
end

