function [KS, pvalueKS, tau] = TestChangePointCopula(X, N, est)
%
%  Nonparametric change point test for a copula  using the 
%  Kolmogorov-Smirnov  statistic.
%
% Input
%        X: (n x d) matrix of data (residuals or observations);
%        N: number of multipliers samples to compute the P-value;
%      est: 1 if tau is estimated, 0 otherwise (default).
%
%  Output
%          KS: Kolmogorov-Smirnov statistic; 
%      Pvalue: (%) calculated with N bootstrap samples;
%         tau: estimation of change point time;
%     tau_rel: estimation of change point relative time (percent of the
%              sample size).
%
%   Ref: Remillard, B. (2012)  Non-Parametric Change Point Problems 
%        Using Multipliers, SSRN Working Paper Series No. 2043632.
%
%%
if nargin < 3
    est = 0;
end

tau = [];


[n,d] = size(X);

M = zeros(n,n);
Un = ones(n,d);
%%
 for j=1:n
       u = X(j,:);
       uu = repmat(u,n,1);
       
       M(:,j) = prod( Un .*(X <= uu), 2 );
       
 end
 %%
C = repmat(mean(M),n,1);
MC = M-C;

MM = cumsum(MC)/sqrt(n);


K = max(abs(MM'));

KS = max(K');
%%
if(est)
 tau = 0;



tau=1; 
   while( K(tau)< KS)
       tau = tau+1;
   end
end 
   
 

%%
 simKS = zeros(N,1);

parfor k=1:N
    xi = randn(n,1);
    
    MCxi = repmat(xi,1,n) .* MC;
    
   MMxi = cumsum(MCxi)/sqrt(n);
   K = max(abs(MMxi'));

  simKS(k) = max(K');
end

pvalueKS = 100*mean (simKS>KS);
   