function out = EstSchwartz(y,tau,r)

[n,d] = size(tau);

options =  optimset(    'largescale',       'off', ...
                        'MaxFunEvals',      10000, ...
                        'MaxIter',          2000, ...
                        'Display',          'iter', ...
                        'diagnostics',      'on');

initialGuess = [.1; log(1); 0 ; log(.2); log(.2) ; 0.5*log(1.8/.3) ; .1; log(1)*ones(d,1)];
                
                              

[theta, LL, exitflag] = fminunc( @( x ) sum( LogligSchwartz( x, y, tau, r )), initialGuess, options);

  exitflag
  
  
  mu     = theta(1);
  kappa  = exp(theta(2));
  alpha  = theta(3);
  sigma1 = exp(theta(4));
  sigma2 = exp(theta(5));
  rho    = tanh(theta(6));
  lambda = theta(7);
  Rvol   = exp( theta(8:7+d) ) ;
  
  param = [mu; kappa ;alpha ;sigma1; sigma2; rho; lambda; Rvol]; 
%% Computation of the filter
[L, Zhat, Phat] = LogligSchwartz( theta, y,  tau , r);



 addpath('../ChapterB')
J = NumJacobian( @(x) LogligSchwartz( x, y, tau, r ), theta, 0.001 );
rmpath('../ChapterB')
 
% Estimation of Fisher's information
FI  = cov(J);  

D           = diag( [1; kappa; 1; sigma1; sigma2; 1-rho^2 ; 1 ; Rvol] );
Covariance  = D * inv( FI ) * D;
error       = 1.96 * sqrt( diag( Covariance ) / n );

names = {'mu    ', 'kappa ', 'alpha ', 'sigma1', 'sigma2', 'rho   ','lambda'};

for j=1:d
    names{j+7} = ['Rvol',num2str(j), ' '];
end
    
out.param.names  = names;
out.param.values = param;
out.param.error  = error;
out.prediction   = Zhat;
out.covariance   = Phat;
out.loglik       = -LL;

 fprintf('\n\n Parameter Estimation Error\n\n');
for j=1: (7+d)
    fprintf(' %6s   %2.4f  %2.4f \n',names{j},param(j),error(j));
end

end

%%
function [L Zhat Phat] = LogligSchwartz(theta,y, tau,r)

   h = 1/252;
  [n,d] = size(tau);
  
 
  
  mu     = theta(1);
  kappa  = exp(theta(2));
  alpha  = theta(3);
  sigma1 = exp(theta(4));
  sigma2 = exp(theta(5));
  rho    = tanh(theta(6));
  lambda = theta(7);
  R      = diag( exp( 2 * theta(8:7+d) ) )*h;
  Q      = [ sigma1^2 rho*sigma1*sigma2;  rho*sigma1*sigma2  sigma2^2]*h;
  Ri = inv(R);
  
  Z0 = [0;0];
  P0 = diag([1;1]);
  
  [Fut A B] = FuturesSchwartz(1,1,tau,r,kappa,alpha,sigma1,sigma2,rho,lambda);
  
  
  
  phi = exp( -kappa * h ) ;
  G   = (1-phi)/kappa;
  mu2 = alpha * kappa * G ;
  mu1 = h * (mu - 0.5 * sigma1^2 -alpha ) + alpha * G ;
  v   = sigma2^2/kappa;
 cov  =  rho*sigma1*sigma2;
 F    = [ 1 -G; 0 phi];
 
  mu  = [mu1'; mu2];
 Zhat = zeros(2,n);
 Phat = zeros(2,2,n);
 
 e = zeros(d,1);
 V = zeros(d,d);
 P = zeros(d,d);
 Pi = P;
 Z = zeros(d,1);
 
 %%
 Z           =  mu +  F * Z0;
 H           = [ ones(d,1)  -B(1,:)'];
 e           = y(1)' - A(1,:)' - H*Z;
 P           = F * P0 * F' + Q;
 V           = R + H * P * H';
 Pi          = inv(P) + H' * Ri * H;
 Phat(:,:,1) = inv(Pi);
 Zhat(:,1)   = Z + Phat(:,:,1) * H' * Ri * e;
 L(1)        = 0.5 * (   log( 2* pi * det( V ) ) + e' * inv(V) * e );
 %%
 
 for i=2:n
   Z           =  mu +  F*Zhat(:,1);
   H           = [ ones(d,1) -B(i,:)'];
   e           = y(i)' - A(i,:)' - H*Z;
   P           = F * Phat(:,:,i-1) * F' + Q;
   V           = R + H * P * H';
   Pi          = inv(P) + H' * Ri * H;
   Phat(:,:,i) = inv(Pi);
   Zhat(:,i)   = Z + Phat(:,:,i-1) * H' * Ri * e;
   L(i)        = 0.5 * (   d * log( 2* pi)  + log( det( V ) ) + e' * inv(V) * e );
 end
end