function [y,z] = SimSV(omega,phi,sigma,n);
% Generates the stochastic volatility model of Ruiz (1994):
%
%   Z_i = omega + phi Z_{i-1} +w_i, w_i \sim N(0,sigma^2),
%   Y_i = \epsilon_i x exp(Z_i/2), \epsilon_i \sim N(0,1).
%
% Exemple: [y,z] = SimSV(-.1,.75,.25,2500);

V_t=omega/(1-phi);
z=ones(n,1);

for t=1:1:n-1
   V_t=omega+phi*V_t+sigma.*randn;
   
   z(t+1)= V_t;

   
end

y = exp(0.5*z).*randn(n,1);