function  out = DescStats(X)
% This function computes descritives statistics for several random
% variables.
%
% Input 
%         X: n x d matrix of data
%
% Output:
%         out: list of the following statistics: mean, median, volatility, 
%              skewness, kurtosis, minimum, maximum, 99%% quantile, RMSE. 
%              Here the MSE is the average sum of the squares.
%
%
%% Computations
mu = mean(X);
vol = std(X);
sk = skewness(X);
ku = kurtosis(X);
m= min(X);
M = max(X);
VaR1 = quantile(X,0.99);
med = median(X);

RMSE = sqrt( mu.^2+vol.^2);

out.mean     = mu;
out.median   = med;
out.vol      = vol;
out.skewness = sk;
out.kurtosis = ku
out.min      = m;
out.max      = M;
out.var      = VaR1;
out.rmse     = RMSE;


[n,d] = size(X);
%%  printed output
fprintf('\n')
fprintf('Average    ')
for j=1:d
fprintf('  %4.4f',mu(j))
end

fprintf('\n')
fprintf('Median     ')
for j=1:d
fprintf('  %4.4f',med(j))
end


fprintf('\n')
fprintf('Volatility ')
for j=1:d
fprintf('  %4.4f',vol(j))
end


fprintf('\n')
fprintf('Skewness   ')
for j=1:d
fprintf('  %4.4f',sk(j))
end


fprintf('\n')
fprintf('Kurtosis   ')
for j=1:d
fprintf('  %4.4f',ku(j))
end

fprintf('\n')
fprintf('Minimum    ')
for j=1:d
fprintf('  %4.4f',m(j))
end


fprintf('\n')
fprintf('Maximum    ')
for j=1:d
fprintf('  %4.4f',M(j))
end

fprintf('\n')
fprintf('VaR(99%%)   ')
for j=1:d
fprintf('  %4.4f',VaR1(j))
end

fprintf('\n')
fprintf('RMSE       ')
for j=1:d
fprintf('  %4.4f',RMSE(j))
end

fprintf('\n\n')