function [H] = NumHessian( NameFunction, x, prec )
% Compute the symmetric numerical second order derivatives of a
% multivariate function
%
% Inputs: NameFunction: name of a function returning a N x 1 vector,
%         x: point at which the derivatives will be computed,
%         prec: percentage of +\- around x (in fraction).
%
% Output: H ( d x d x n) sequence of Hessian matrices.

d = length( x );
for ii = 1:d
    x2 = x;
    x1 = x;
    x1( ii ) = x1( ii ) * ( 1 - prec );
    x2( ii ) = x1( ii ) * ( 1 + prec );
    for j = 1:d
        y11 = x1;
        y21 = x2;
        y12 = x1;
        y22 = x2;
        y11( j ) = y11( j ) * ( 1 - prec );
        y12( j ) = y12( j ) * ( 1 + prec );
        y21( j ) = y21( j ) * ( 1 - prec );
        y22( j ) = y22( j ) * ( 1 + prec );
        H(ii,j,:) = ( ( NameFunction(y11) - NameFunction(y12) ) ./ ( y11( j ) - y12( j ) ) - ( NameFunction(y21) - NameFunction(y22) ) ./ ( y21( j ) - y22( j ) ) ) / ( x1( ii ) - x2( ii ) );
    end
end